@@ -132,6 +132,18 @@ public :
 
     bool isChannelName(const QString &channelname) const;
 
+    /**
+     * Checks if the target counts as a STATUSMSG
+     *
+     * Status messages are prefixed with one or more characters from the server-provided STATUSMSG
+     * if available, otherwise "@" and "+" are assumed.  Generally, status messages sent to a
+     * channel are only visible to those with the same or higher permissions, e.g. voiced.
+     *
+     * @param[in] target Name of destination, e.g. a channel or query
+     * @returns True if a STATUSMSG, otherwise false
+     */
+    bool isStatusMsg(const QString &target) const;
+
     inline bool isConnected() const { return _connected; }
     //Network::ConnectionState connectionState() const;
     inline int connectionState() const { return _connectionState; }
