@@ -35,9 +35,6 @@
 #  define MultiLineEditParent QTextEdit
 #endif
 
-class QKeyEvent;
-class TabCompleter;
-
 class MultiLineEdit : public MultiLineEditParent
 {
     Q_OBJECT
@@ -76,6 +73,8 @@ public:
     inline qint32 idx() const { return _idx; }
     inline bool emacsMode() const { return _emacsMode; }
 
+    void addCompletionSpace();
+
 public slots:
     void setMode(Mode mode);
     void setMinHeight(int numLines);
@@ -101,7 +100,7 @@ protected:
 
 private slots:
     void on_returnPressed();
-    void on_returnPressed(const QString &text);
+    void on_returnPressed(QString text);
     void on_textChanged();
     void on_documentHeightChanged(qreal height);
 
@@ -124,6 +123,7 @@ private:
     bool _scrollBarsEnabled;
     bool _pasteProtectionEnabled;
     bool _emacsMode;
+    int _completionSpace;
 
     QSize _sizeHint;
     qreal _lastDocumentHeight;
