@@ -152,7 +152,7 @@ void TabCompleter::complete()
             _lastCompletionLength += _nickSuffix.length();
         }
         else if (s.addSpaceMidSentence()) {
-            _lineEdit->insert(" ");
+            _lineEdit->addCompletionSpace();
             _lastCompletionLength++;
         }
 
